Package 'AAGITemplates'

Title: Add AAGI Templates to `New Rmarkdown` Window
Description: Clicking the RStudio New Rmarkdown button shows a window where various Rmarkdown templates can be selected. This package adds AAGI reporting templates in this window as an easy way to add required template files such as logos, styling and initialisation scripts when creating a new report.
Authors: Sam Rogers [aut, cre] (ORCID: <https://orcid.org/0000-0002-4607-5396>), Julian Taylor [aut] (ORCID: <https://orcid.org/0000-0002-9145-052X>), Russell Edson [aut] (ORCID: <https://orcid.org/0000-0002-4607-5396>)
Maintainer: Sam Rogers <[email protected]>
License: MIT + file LICENSE
Version: 0.6.0
Built: 2026-05-13 08:54:59 UTC
Source: https://github.com/AAGI-AUS/AAGITemplates

Help Index


Create a new AAGI Report using a template

Description

Create a new AAGI Report using a template

Usage

new_report(
  filename,
  type = c("aagi_report", "html_presentation", "short_report", "knitr_report",
    "latex_report", "beamer_presentation")
)

Arguments

filename

The filename of the report.

type

The type of the report. Partial matching is performed.

  • aagi_report (default): A full AAGI report using Rmarkdown.

  • html_presentation: An AAGI slide presentation in HTML, using Rmarkdown/xaringan.

  • short_report: A short one-page AAGI report using Rmarkdown.

  • knitr_report: A full AAGI report using knitr.

  • latex_report: A full AAGI report using LaTeX (without embedded R/chunks).

  • beamer_presentation: An AAGI slide presentation in LaTeX, using Beamer (without embedded R/chunks).

Value

Returns the path to the created file invisibly.

Examples

## Not run: 
new_report(filename = "test_report", type = "aagi_report")

## End(Not run)