| Title: | Add AAGI Templates to `New Rmarkdown` Window |
|---|---|
| Description: | Clicking the RStudio New Rmarkdown button shows a window where various Rmarkdown templates can be selected. This package adds AAGI reporting templates in this window as an easy way to add required template files such as logos, styling and initialisation scripts when creating a new report. |
| Authors: | Sam Rogers [aut, cre] (ORCID: <https://orcid.org/0000-0002-4607-5396>), Julian Taylor [aut] (ORCID: <https://orcid.org/0000-0002-9145-052X>), Russell Edson [aut] (ORCID: <https://orcid.org/0000-0002-4607-5396>) |
| Maintainer: | Sam Rogers <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.6.0 |
| Built: | 2026-05-13 08:54:59 UTC |
| Source: | https://github.com/AAGI-AUS/AAGITemplates |
Create a new AAGI Report using a template
new_report( filename, type = c("aagi_report", "html_presentation", "short_report", "knitr_report", "latex_report", "beamer_presentation") )new_report( filename, type = c("aagi_report", "html_presentation", "short_report", "knitr_report", "latex_report", "beamer_presentation") )
filename |
The filename of the report. |
type |
The type of the report. Partial matching is performed.
|
Returns the path to the created file invisibly.
## Not run: new_report(filename = "test_report", type = "aagi_report") ## End(Not run)## Not run: new_report(filename = "test_report", type = "aagi_report") ## End(Not run)